import {
  ModalForm,
  ProFormSelect,
  ProFormText,
  ProFormRadio,
  ProFormTextArea,
  ProFormUploadButton,
  ProForm,
} from '@ant-design/pro-components'
import { Button, Col, message, Form } from 'antd'
import { useState } from 'react'
import {testDataSourceConnection, createDataSource} from '../services'

const DATA_TYPE_MYSQL = 'mysql'
const KERBS_VALID_FALSE = false

export default function DatasourceAdd({updateDataSource}) {
  // 数据源类型
  const [dataType, setDataType] = useState(DATA_TYPE_MYSQL)
  // 是否开启kerbsValid验证
  const [kerbsValid, setKerbsValid] = useState(KERBS_VALID_FALSE)
  // Loading状态
  const [loading, setLoading] = useState(false)
  // Form表单
  const [form] = Form.useForm()
  // 测试连接
  const testConnect = async () => {
    const filds = ['datasource_name','datasource','database_name','jdbc_username','jdbc_password','jdbc_url','comments', 'tag']
    try {
      await form.validateFields(filds)
      setLoading(true)
      const testData = form.getFieldsValue(filds)
      const { data } = await testDataSourceConnection(testData)
      if (data.data) {
        message.success('连接成功')
      } else {
        message.error('连接失败')
      }
    } catch (error) {
      message.error('表单验证错误，请检查表单信息是否完整')
    }
    setLoading(false)
  }
  // 完成添加
  const finishAdd = async () => {
    const filds = ['datasource_name','datasource','database_name','jdbc_username','jdbc_password','jdbc_url','comments', 'tag']
    const { data } = await createDataSource(form.getFieldsValue(filds))
    if (data.code === 200) {
      message.success('添加成功')
      updateDataSource()
    } else {
      message.error('添加失败，请检查数据')
    }
    return true
  }
  // 测试连接按钮
  const testConnectBtn = (
    <Button onClick={testConnect} loading={loading}>
      测试连接
    </Button>
  )
  return (
    <ModalForm
      form={form}
      trigger={
        <Button type="primary">添加数据源</Button>
      }
      onFinish={finishAdd}
      initialValues={{
        datasource: DATA_TYPE_MYSQL,
        kerbsValid: KERBS_VALID_FALSE,
        comments: ''
      }}
      title="添加数据源"
      modalProps={{
        destroyOnClose: true,
        width: '60%',
        afterClose: () => {
          setDataType(DATA_TYPE_MYSQL)
          setKerbsValid(KERBS_VALID_FALSE)
          form.resetFields()
        },
        okText: '确认添加',
      }}
      layout="horizontal"
      grid={true}
      labelCol={{ span: 7 }}
      colProps={{ span: 12 }}
      rowProps={{
        gutter: [45, 0],
      }}>
      <ProFormSelect
        label="选择数据源"
        name="datasource"
        fieldProps={{
          onChange: val => setDataType(val),
        }}
        valueEnum={{
          mysql: 'My SQL',
          hive: 'hive',
        }}
        rules={[
          {
            required: true,
            message: '请选择数据源!',
          },
        ]}
      />
      <Col span={12} />
      <ProFormText
        label="数据源名称"
        name="datasource_name"
        rules={[
          {
            required: true,
            message: '请输入数据源名称!',
          },
        ]}
      />
      <ProFormSelect
        label="数据源标签"
        name="tag"
        valueEnum={{
          '线上': '线上',
          '测试': '测试',
          '开发': '开发',
        }}
        rules={[
          {
            required: true,
            message: '请选择数据源标签!',
          },
        ]}
      />
      <ProFormText
        label="数据库地址"
        name="jdbc_url"
        rules={[
          {
            required: true,
            message: '请输入数据库地址!',
          },
        ]}
      />
      <ProFormText
        label="数据库名称"
        name="database_name"
        rules={[
          {
            required: true,
            message: '请输入数据库名称!',
          },
        ]}
      />
      <ProFormText
        label="用户名"
        name="jdbc_username"
        rules={[
          {
            required: true,
            message: '请输入用户名!',
          },
        ]}
      />
      <ProFormText.Password
        label="密码"
        name="jdbc_password"
        rules={[
          {
            required: true,
            message: '请输入密码!',
          },
        ]}
      />
      <ProFormTextArea
        label="详情"
        name="comments"
        fieldProps={{ autoSize: true }}
      />
      {dataType === 'hive' ? (
        <ProFormRadio.Group
          label="kerbs验证"
          name="kerbsValid"
          fieldProps={{
            onChange: e => setKerbsValid(e.target.value),
          }}
          options={[
            {
              label: '是',
              value: true,
            },
            {
              label: '否',
              value: false,
            },
          ]}
        />
      ) : (
        <></>
      )}

      <Col span={12} style={{ paddingLeft: '22.5px', paddingRight: '22.5px' }}>
        <ProForm.Item label="测试连接" name="success">
          {testConnectBtn}
        </ProForm.Item>
      </Col>

      {dataType === 'hive' && kerbsValid ? (
        <>
          <ProFormUploadButton
            label="keytab"
            name="keytab"
            action="upload.do"
            title="上传keyTabPath"
            max={1}
          />
          <Col span={12} />
          <ProFormUploadButton
            label="krd5config"
            name="krd5config"
            action="upload.do"
            title="上传kard5config"
            max={1}
          />
          <Col span={12} />
          <ProFormText
            label="Principal"
            name="principal"
            placeholder="ylaiuser@EMR-56L6ZNTS"></ProFormText>
        </>
      ) : (
        <></>
      )}
    </ModalForm>
  )
}
