import React, { useState, useEffect } from 'react'
import { Table, Space } from 'antd'
import { getJoblog } from '../services'
import moment from 'moment'
import { useNavigate } from 'react-router-dom'

const DatasourceLog = () => {
  // 初始化日志列表
  const [logList, setLogList] = useState([])
  // 表格Loading状态
  const [dataLoading, setDataLoading] = useState(false)

  const navigate = useNavigate()

  const changeTask = () => {}
  const checkLog = id => {
    navigate('/log', { state: { id } })
  }
  const columns = [
    {
      title: '同步ID',
      dataIndex: 'jobId',
      key: 'jobId',
    },
    {
      title: '调度时间',
      dataIndex: 'triggerTime',
      key: 'triggerTime',
    },
    {
      title: '调度结果',
      dataIndex: 'triggerResult',
      key: 'triggerResult',
      render: code => (
        <span
          style={{
            color: code === 0 ? '#FF4D4F' : code === 1 ? '#52C41A' : '#4A4A4A',
          }}>
          {code === 0 ? '失败' : code === 1 ? '成功' : '无'}
        </span>
      ),
    },
    {
      title: '执行时间',
      dataIndex: 'handleTime',
      key: 'handleTime',
    },
    {
      title: '执行结果',
      dataIndex: 'handleResult',
      key: 'handleResult',
      render: code => (
        <span
          style={{
            color: code === 0 ? '#FF4D4F' : code === 1 ? '#52C41A' : '#4A4A4A',
          }}>
          {code === 0 ? '失败' : code === 1 ? '成功' : '无'}
        </span>
      ),
    },
    {
      title: '操作',
      key: 'operation',
      render: (_, record) => (
        <Space size="middle">
          <span
            onClick={() => {
              checkLog(record.key)
            }}
            style={{ color: '#1881DA', cursor: 'pointer' }}>
            查看
          </span>
          {/* <a href="/#" onClick={editData} style={{ color: '#1881DA' }}>
            编辑
          </a> */}
          <span
            onClick={() => {
              changeTask(record.key)
            }}
            style={{ color: '#1881DA', cursor: 'pointer' }}>
            终止任务
          </span>
        </Space>
      ),
    },
  ]

  const fetchJoblog = async () => {
    setDataLoading(true)
    const { data } = await getJoblog()
    if (data.code === 200) {
      const list = data.data.items.map(item => {
        return {
          key: item.id,
          jobId: item.job_id,
          triggerTime: moment(item.trigger_time).format('YYYY.MM.DD HH:MM'),
          triggerResult: item.trigger_code,
          handleTime: moment(item.handle_time).format('YYYY.MM.DD HH:MM'),
          handleResult: item.handle_code,
        }
      })
      setLogList(list)
    }
    setDataLoading(false)
  }

  useEffect(() => {
    fetchJoblog()
  }, [])

  return (
    <Table
      columns={columns}
      dataSource={logList}
      bordered
      loading={dataLoading}
    />
  )
}

export default DatasourceLog
