import React, { useState } from 'react'
import { Form, Select, Input, DatePicker, Row, Col, InputNumber } from 'antd'
export default function StepFour({ syncDataForm }) {
  const [showPartitionTime, setShowPartitionTime] = useState(false)
  return (
    <>
      <p
        style={{
          fontWeight: 600,
          borderLeft: '3px solid #1881DA',
          paddingLeft: '12px',
        }}>
        设置同步参数
      </p>
      <Form
        name="syncForm"
        form={syncDataForm}
        labelCol={{
          span: 2,
        }}
        wrapperCol={{
          span: 6,
        }}
        initialValues={{
          partition_info: '',
          replace_param: '',
          executor_timeout: 0,
          executor_fail_retry_count: 0
        }}
      >
        <Form.Item
          label="路由策略"
          name="executor_route_strategy"
          rules={[
            {
              required: true,
              message: '请选择路由策略',
            },
          ]}>
          <Select
            options={[
              {label: '第一个', value: 'FIRST'},
              {label: '最后一个', value: 'LAST'}
            ]}
            allowClear
          />
        </Form.Item>
        <Form.Item
          label="阻塞处理方式"
          name="executor_block_strategy"
          rules={[
            {
              required: true,
              message: '请选择阻塞处理方式',
            },
          ]}>
          <Select
            options={[
              {label: '单机串行', value: 'SERIAL_EXECUTION'},
            ]}
            allowClear
          />
        </Form.Item>
        <Form.Item
          label="超时时间"
          name="executor_timeout"
          required
        >
          <InputNumber min={0} />
        </Form.Item>
        <Form.Item
          label="失败重试次数"
          name="executor_fail_retry_count"
          required
        >
          <InputNumber  min={0} />
        </Form.Item>
        <Form.Item
          label="增量开始时间"
          name="inc_start_time"
          rules={[
            {
              required: true,
              message: '请选择增量开始时间',
            },
          ]}>
          <DatePicker showTime/>
        </Form.Item>
        <Form.Item
          label="增量时间字段"
          name="replace_param"
        >
          <Input />
        </Form.Item>
        <Row span={24}>
          <Col span={8}>
            <Form.Item
              label="区分字段"
              name="partition_info"
              labelCol={{
                span: 6,
              }}
              wrapperCol={{
                span: 18,
              }}>
              <Input
                onChange={e => {
                  if (e.target.value && !showPartitionTime) {
                    setShowPartitionTime(true)
                  } else if (!e.target.value && showPartitionTime) {
                    setShowPartitionTime(false)
                  }
                }}
              />
            </Form.Item>
          </Col>
          {showPartitionTime ? (
            <>
              <Col span={8}>
                <Form.Item
                  label="分区时间"
                  name="partition_time"
                  labelCol={{
                    span: 12,
                  }}
                  wrapperCol={{
                    span: 12,
                  }}>
                  <Input placeholder="yyyy-MM-dd" />
                </Form.Item>
              </Col>
              <Col>
                <InputNumber defaultValue={0} style={{ marginLeft: '10px' }} />
              </Col>
            </>
          ) : (
            ''
          )}
        </Row>
        <Form.Item
          label="定时规则"
          name="job_cron"
          rules={[
            {
              required: true,
              message: '请输入定时规则',
            },
          ]}>
          <Input />
        </Form.Item>
        <Form.Item
          label="同步任务名称"
          name="job_desc"
          rules={[
            {
              required: true,
              message: '请输入定时规则',
            },
          ]}>
          <Input />
        </Form.Item>
      </Form>
    </>
  )
}
