import React, { useState, useEffect } from 'react'
import { Form, Select, Input, message } from 'antd'
import { getTableNamesList } from '../services'

export default function LoadFormConfig({ loadDataForm, dataSourceList, updateTableStruct }) {
  const [datasourceType, setDatasourceType] = useState(null)

  const [datasources, setDatasources] = useState()

  const [tableList, setTableList] = useState([])

  // 获取数据源列表
  useEffect(() => {
    if (dataSourceList.length !== 0) {
      setDatasources(
        dataSourceList.map(item => {
          return {
            label: item.datasource_name,
            value: item.key,
          }
        })
      )
    }
  }, [dataSourceList])

  // 初始化表单类型
  useEffect(() => {
    const ds_id = loadDataForm.getFieldValue('datasource_name')
    const table_name = loadDataForm.getFieldValue('datasource_table')
    if (ds_id) {
      const type = dataSourceList.find(item => item.key === ds_id).datasource
      setDatasourceType(type)
      selectDatasource(ds_id)
      loadDataForm.setFieldValue('datasource_table', table_name)
    }
  }, [])

  // 选择数据源
  const selectDatasource = async val => {
    loadDataForm.setFieldValue('datasource_table', null)
    const type = dataSourceList.find(item => item.key === val).datasource
    setDatasourceType(type)
    const { data } = await getTableNamesList(val)
    if (data.code === 200) {
      const list = data.data.map(item => ({
        label: item,
        value: item,
      }))
      setTableList(list)
    } else {
      message.error('数据表加载失败')
    }
  }

  // 选择表
  const selectTable = (val) => {
    const ds_id = loadDataForm.getFieldValue('datasource_name')
    updateTableStruct(ds_id, val)
  }

  return (
    <>
      <p
        style={{
          fontWeight: 600,
          borderLeft: '3px solid #1881DA',
          paddingLeft: '12px',
        }}>
        配置加载源源
      </p>
      <Form
        name="drawForm"
        form={loadDataForm}
        labelCol={{
          span: 2,
        }}
        wrapperCol={{
          span: 6,
        }}
        initialValues={{
          pre_sql: '',
          post_sql: '',
          writer_field_delimiter: ''
        }}
      >
        <Form.Item
          label="选择数据源"
          name="datasource_name"
          rules={[
            {
              required: true,
              message: '请选择数据源!',
            },
          ]}>
          <Select
            options={datasources}
            onSelect={selectDatasource}
            allowClear
          />
        </Form.Item>
        <Form.Item
          label="选择表"
          name="datasource_table"
          rules={[
            {
              required: true,
              message: '请选择表',
            },
          ]}>
          <Select options={tableList} allowClear onSelect={selectTable} />
        </Form.Item>
        {datasourceType === 'mysql' ? (
          <>
            <Form.Item label="pre_sql" name="pre_sql" wrapperCol={{ span: 10 }}>
              <Input.TextArea rows={5} />
            </Form.Item>
            <Form.Item label="post_sql" name="post_sql" wrapperCol={{ span: 10 }}>
              <Input.TextArea rows={5} />
            </Form.Item>
          </>
        ) : (
          <>
            <Form.Item
              label="选择路径"
              name="writer_path"
              wrapperCol={{ span: 10 }}
              rules={[
                {
                  required: true,
                  message: '请选择路径!',
                },
              ]}>
              <Input.TextArea rows={5} placeholder="要读取的文件路径" />
            </Form.Item>
            <Form.Item
              label="HDFS"
              name="writer_default_fs"
              rules={[
                {
                  required: true,
                  message: '请输入HDFS',
                },
              ]}>
              <Input placeholder="Hadoop hdfs文件系统namenode节点地址" />
            </Form.Item>
            <Form.Item
              label="文件类型"
              name="writer_file_type"
              rules={[
                {
                  required: true,
                  message: '请选择文件类型',
                },
              ]}>
              <Select
                options={[
                  { label: 'text', value: 'text' },
                  { label: 'csv', value: 'csv' },
                  { label: 'ocr', value: 'ocr' },
                ]}
                allowClear
                placeholder="文件的类型"
              />
            </Form.Item>
            <Form.Item
              label="写入模式"
              name="writer_mode"
              rules={[
                {
                  required: true,
                  message: '请选择写入模式',
                },
              ]}>
              <Select
                options={[
                  { label: '追加', value: 'append' },
                  { label: '覆盖', value: 'cover' },
                ]}
                allowClear
                placeholder="写入模式"
              />
            </Form.Item>
            <Form.Item label="分隔符" name="writer_field_delimiter">
              <Input placeholder="读取字段的分隔符" />
            </Form.Item>
          </>
        )}
      </Form>
    </>
  )
}
